Exceptions
==========

.. currentmodule:: fastobo.exceptions
.. automodule:: fastobo.exceptions


Cardinality Errors
------------------

.. autoexception:: MissingClauseError


.. autoexception:: DuplicateClausesError


.. autoexception:: SingleClauseError


Threading Errors
----------------

.. autoexception:: DisconnectedChannelError
